\_recommended: Represents system packages recommended for additional functionality
==================================================================================

Description
-----------

Script package representing a list of system packages recommended to be
installed for additional functionality.
